@@ -287,8 +287,8 @@ class World:
                 "namespace": "",
             },
         )
-        pose: "World.Include.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["World.Include.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -307,7 +307,7 @@ class World:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -438,8 +438,8 @@ class World:
                     "namespace": "",
                 },
             )
-            pose: "World.Gui.Camera.Pose" = field(
-                default="0 0 0 0 0 0",
+            pose: Optional["World.Gui.Camera.Pose"] = field(
+                default=None,
                 metadata={
                     "type": "Element",
                     "namespace": "",
@@ -564,7 +564,7 @@ class World:
                 """
 
                 value: str = field(
-                    default="",
+                    default="0 0 0 0 0 0",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -635,8 +635,8 @@ class World:
             world frame.
         """
 
-        pose: "World.Frame.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["World.Frame.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -668,7 +668,7 @@ class World:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -904,8 +904,8 @@ class World:
                 "namespace": "",
             },
         )
-        pose: "World.Population.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["World.Population.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -1047,7 +1047,7 @@ class World:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
